@@ -76,17 +76,17 @@ WEBKIT_API void
 webkit_settings_set_auto_load_images                           (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_load_icons_ignoring_image_load_setting     (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_load_icons_ignoring_image_load_setting     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_offline_web_application_cache       (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_offline_web_application_cache       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -457,6 +457,28 @@ webkit_settings_get_disable_web_security                       (WebKitSettings *
 WEBKIT_API void
 webkit_settings_set_disable_web_security                       (WebKitSettings *settings,
                                                                 gboolean        disabled);
+
+typedef struct _WebKitFeature WebKitFeature;
+typedef struct _WebKitFeatureList WebKitFeatureList;
+
+WEBKIT_API void
+webkit_settings_set_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature,
+                                                                gboolean        enabled);
+
+WEBKIT_API gboolean
+webkit_settings_get_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_all_features                               (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_experimental_features                      (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_development_features                       (void);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
